==> pyRSD-0.1.3.tar.gz: class_public-2.5.0/doc/manual/html/navtreedata.js <==
var NAVTREE =
[
  [ "CLASS MANUAL", "index.html", [
    [ "CLASS: Cosmic Linear Anisotropy Solving System", "index.html", null ],
    [ "Where to find information and documentation on CLASS?", "md_chap2.html", null ],
    [ "CLASS: Cosmic Linear Anisotropy Solving System", "md_chap3.html", null ],
    [ "The `external_Pk` mode", "md__home_deannah88_Documents_Uni_stuff_Master_Student_Job_class_doxygen_class_external_Pk_README.html", null ],
    [ "Updating the manual", "md_mod.html", null ],
    [ "Data Structures", null, [
      [ "Data Structures", "annotated.html", "annotated" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"common_8h.html#aa6bf73c3bb587fcaf367ac9d43798bcd",
"output_8h_source.html",
"perturbations_8h.html#adda35d646eba2eabc09a21861effb845",
"spectra_8h.html#a82a56f7919678728f1a9b695deabc104",
"transfer_8h.html#a103c59aede115134d0063b78081b3075"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pyRSD-0.1.5.tar.gz: class_public-2.6.0/doc/manual/html/navtreedata.js <==
var NAVTREE =
[
  [ "CLASS MANUAL", "index.html", [
    [ "CLASS: Cosmic Linear Anisotropy Solving System", "index.html", null ],
    [ "Where to find information and documentation on CLASS?", "md_chap2.html", null ],
    [ "CLASS overview (architecture, input/output, general principles)", "md_chap3.html", null ],
    [ "The `external_Pk` mode", "md__Users_lesgourg_OwnCloud_documents_codes_ClassProject_class_external_Pk_README.html", null ],
    [ "Updating the manual", "md_mod.html", null ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"common_8h.html#a97d5f791e87f30f894a5ba0f0a8eed5a",
"parser_8h_source.html",
"perturbations_8h.html#ad60d11a36d328dedd1b02871e6b8f2d1",
"spectra_8h.html#a6bf91ee144fcebf9e6f7c24f3275c072",
"transfer_8c.html#a0fcf8cc8e561263cdc2d3d39cebd9a5d"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
